AuthRoute class

Represents a route in the authentication system.

Provides two constructors:

Constructors

AuthRoute.builder(String path, Widget builder(BuildContext context, Object? arguments)?)
Creates an AuthRoute with a dynamic builder.
AuthRoute.static(String path, Widget? widget)
Creates an AuthRoute with a static widget.

Properties

builder Widget Function(BuildContext context, Object? arguments)?
Optional builder function that receives BuildContext and route arguments.
final
hashCode int
The hash code for this object.
no setterinherited
path String
The route name/path used for navigation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget Widget?
Optional static widget to display for this route.
final

Methods

build(BuildContext context) Widget
Builds the widget for this route.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited